@@ -101,7 +101,7 @@ sub setup_entry {
   # The validation function will receive the new string and the event 'key' or
   # 'forced' (could be 'focusin' or 'focusout' but we don't validate on these
   # event).
-  $widget->m_configure(-validate => 'none', -validatecommand => [ $validate, Tkx::Ev('%P', '%V')]);
+  $widget->m_configure(-validate => 'none', -validatecommand => [ sub { $has_changes = 1; $validate->(@_) }, Tkx::Ev('%P', '%V')]);
 }
 
 my $currently_selected;
